// Rotating filter tutorial

use crate::game::*;

use bevy::prelude::*;

pub fn setup(
	commands: &mut Commands,
	meshes: &mut ResMut<Assets<Mesh>>,
	character_meshes: &Res<CharacterMeshes>,
	materials: &mut ResMut<Assets<ColorMaterial>>,
	audio: &Res<crossbeam_channel::Sender<AudioMsg>>,
	asset_server: &Res<AssetServer>,
) {
	let font = asset_server.get_handle("UacariLegacy-Thin.ttf");
	commands
		.spawn_bundle(Text2dBundle {
			text: Text::from_section(
				"Let's rotate the hue!",
				TextStyle {
					font,
					font_size: 32.0,
					color: Color::WHITE,
				},
			)
			.with_alignment(TextAlignment::CENTER),
			..Default::default()
		})
		.insert(Level);

	spawn_platforms(
		commands,
		meshes,
		materials,
		[(
			Transform::from_xyz(0.0, -256.0, 0.0),
			Vec2 { x: 800.0, y: 16.0 },
		)],
	);

	spawn_characters(
		commands,
		character_meshes,
		materials,
		audio,
		[
			(Transform::from_xyz(0., -192., 0.), Color::RED),
			(Transform::from_xyz(-128., -192., 0.), Color::RED),
			(Transform::from_xyz(128., -192., 0.), Color::RED),
		],
	);

	spawn_rotating_filter(
		commands,
		asset_server,
		Transform::from_xyz(0., -64., 2.),
		45.,
	);
}
